==> yos.core-1.0.0-sources.jar: restcontroller/sysmanage/develop/datamag/uniquecolumnmaxid/uniquecolumnmaxid.java <==
package restcontroller.sysmanage.develop.datamag.uniquecolumnmaxid;

import com.alibaba.fastjson.JSONObject;
import common.Controller;
import common.YosException;
import common.annotation.API;
import common.data.Row;
import common.data.Rows;
import common.data.RowsMap;
import common.data.SQLFactory;

public class uniquecolumnmaxid extends Controller {
    public uniquecolumnmaxid(JSONObject content) throws YosException {
        super(content);
    }

    @API(title = "数据表ID值查询")
    public String tableIdQuery() throws YosException {
        Rows sys_objectRows = dbConnect.runSqlQuery(new SQLFactory(this, "数据表ID值查询"));

        StringBuffer sqlbuffer = new StringBuffer();
        for (Row sys_objectRow : sys_objectRows) {
            if (!sqlbuffer.toString().equals("")) {
                sqlbuffer.append(" union all ");
            }
            sqlbuffer.append(sys_objectRow.getString("tabledatasql"));
        }
        RowsMap tabledataRows = dbConnect.runSqlQuery(sqlbuffer.toString()).toRowsMap("table_name");
        for (Row sys_objectRow : sys_objectRows) {
            sys_objectRow.put("tabledata", tabledataRows.get(sys_objectRow.getString("table_name")).get(0));
        }
        sys_objectRows.removeColumn(new String[]{"tabledatasql"});
        return getSucReturnObject().setData(sys_objectRows).toString();
    }

    @API(title = "id初始化")
    public String initID() throws YosException {
        String table_name = content.getString("table_name");
        dbConnect.runSqlUpdate("update sys_object set uniquecolumnmaxid=0 where table_name='" + table_name + "'");
        tableidmapClean(table_name);
        createTableID(table_name);
        return getSucReturnObject().toString();
    }


    @API(title = "ID值设置")
    public String setID() throws YosException {
        String table_name = content.getString("table_name");
        long addcount = content.getLong("addcount");
        if (addcount < 0) {
            return getErrReturnObject().setErrMsg("必须为正数").toString();
        } else if (addcount > 0) {
            addcount = addcount - 1;
            dbConnect.runSqlUpdate("update sys_object set uniquecolumnmaxid=uniquecolumnmaxid+" + addcount + " where table_name='" + table_name + "'");
            tableidmapClean(table_name);
            createTableID(table_name);
        }
        return getSucReturnObject().toString();
    }
}

==> yos.core-2.4.17-sources.jar: restcontroller/sysmanage/develop/datamag/uniquecolumnmaxid/uniquecolumnmaxid.java <==
package restcontroller.sysmanage.develop.datamag.uniquecolumnmaxid;

import com.alibaba.fastjson.JSONObject;
import common.Controller;
import common.YosException;
import common.annotation.API;
import common.data.Row;
import common.data.Rows;
import common.data.RowsMap;
import common.data.SQLFactory;
import restcontroller.R;

public class uniquecolumnmaxid extends Controller {
    public uniquecolumnmaxid(JSONObject content) throws YosException {
        super(content);
    }

    @API(title = "数据表ID值查询", apiversion = R.ID10011401.v1.class)
    public String tableIdQuery() throws YosException {
        Rows sys_objectRows = dbConnect.runSqlQuery(new SQLFactory(this, "数据表ID值查询"));

        StringBuffer sqlbuffer = new StringBuffer();
        for (Row sys_objectRow : sys_objectRows) {
            if (!sqlbuffer.toString().equals("")) {
                sqlbuffer.append(" union all ");
            }
            sqlbuffer.append(sys_objectRow.getString("tabledatasql"));
        }
        RowsMap tabledataRows = dbConnect.runSqlQuery(sqlbuffer.toString()).toRowsMap("table_name");
        for (Row sys_objectRow : sys_objectRows) {
            sys_objectRow.put("tabledata", tabledataRows.get(sys_objectRow.getString("table_name")).get(0));
        }
        sys_objectRows.removeColumn(new String[]{"tabledatasql"});
        return getSucReturnObject().setData(sys_objectRows).toString();
    }

    @API(title = "id初始化", apiversion = R.ID10011501.v1.class)
    public String initID() throws YosException {
        String table_name = content.getString("table_name");
        dbConnect.runSqlUpdate("update sys_object set uniquecolumnmaxid=0 where table_name='" + table_name + "'");
        tableidmapClean(table_name);
        createTableID(table_name);
        return getSucReturnObject().toString();
    }


    @API(title = "ID值设置", apiversion = R.ID10011601.v1.class)
    public String setID() throws YosException {
        String table_name = content.getString("table_name");
        long addcount = content.getLong("addcount");
        if (addcount < 0) {
            return getErrReturnObject().setErrMsg("必须为正数").toString();
        } else if (addcount > 0) {
            addcount = addcount - 1;
            dbConnect.runSqlUpdate("update sys_object set uniquecolumnmaxid=uniquecolumnmaxid+" + addcount + " where table_name='" + table_name + "'");
            tableidmapClean(table_name);
            createTableID(table_name);
        }
        return getSucReturnObject().toString();
    }
}
